@@ -2,20 +2,6 @@ from extras.plugins import PluginMenuButton, PluginMenuItem
 from utilities.choices import ButtonColorChoices
 
 menu_items = (
-    PluginMenuItem(
-        link='plugins:netbox_bgp:asn_list',
-        link_text='AS Numbers',
-        permissions=['netbox_bgp.view_asn'],
-        buttons=(
-            PluginMenuButton(
-                link='plugins:netbox_bgp:asn_add',
-                title='AS Numbers',
-                icon_class='mdi mdi-plus-thick',
-                color=ButtonColorChoices.GREEN,
-                permissions=['netbox_bgp.add_asn'],
-            ),
-        ),
-    ),
     PluginMenuItem(
         link='plugins:netbox_bgp:community_list',
         link_text='Communities',
@@ -58,6 +44,20 @@ menu_items = (
             ),
         ),
     ),
+    PluginMenuItem(
+        link='plugins:netbox_bgp:prefixlist_list',
+        link_text='Prefix Lists',
+        permissions=['netbox_bgp.view_prefixlist'],
+        buttons=(
+            PluginMenuButton(
+                link='plugins:netbox_bgp:prefixlist_add',
+                title='Prefix Lists',
+                icon_class='mdi mdi-plus-thick',
+                color=ButtonColorChoices.GREEN,
+                permissions=['netbox_bgp.add_prefixlist'],
+            ),
+        ),
+    ),
     PluginMenuItem(
         link='plugins:netbox_bgp:bgppeergroup_list',
         link_text='Peer Groups',
